function r=lowreg(h,j,K)
%LOWREG Hoelder Regularity
% LOWREG(H) gives a sharp lower bound for the Hoelder regularity order
% of low-pass filter H (it may be negative)
%
% LOWREG(H,j) forces the number of iterations in the algorithm to j.
% By default, j is set to 8.
%
% LOWREG(H,j,k) also forces the number of zeros at z==-1 in H to k. 
% By default, k is estimated by successive division with remainders <1e-3
%
% See also REG, SOBREG in the SIMPA Toolbox

% For MATLAB 4.1
% Author: Olivier Rioul January 4 1995

% References:
% Olivier Rioul, Simple regularity criteria for subdivision schemes,
%    SIAM J. Math. Anal., Vol. 23, No. 6, pp. 1544-1576, Nov. 1992

if min(size(h))~=1, error('input must be a vector'), end
if any(imag(h)), error('input must be real'), end
h=h(:)';

if nargin==1, j=8; nargin=2; end
if j<=0, error('j is negative'); end
nargin=nargin-1;

tol=1e-3;
if nargin>=2
 for k=1:K
  [h,r]=deconv(h,[1 1]);
  if max(abs(r))>tol
    fprintf('Warning in lowreg: remainder=%g\n',max(abs(r)));
  end
 end
else
 K=0;
 [q,r]=deconv(h,[1 1]);  % do .. while
 while max(abs(r))<tol
  h=q; K=K+1; [q,r]=deconv(h,[1 1]);
 end
 fprintf('%g zeroes at z==-1 in filter\n',K);
end

h=h./sum(h);
L=length(h);

if L==1, r=K-1;
else
 x=1;
 for i=1:j
  [m,n]=size(x);
  x=[x;zeros(L,n)];
  x=x(:);
  x=filter(h,1,x);
  m=length(x)/n;
  x=reshape(x,m,n);
  if rem(m,2), m=m+1; x=[x; zeros(1,n)]; end
  x=[x(1:2:m,:) x(2:2:m,:)];
 end
 r=K-1-log2(max(sum(abs(x))))/j;
end
